@@ -13,7 +13,7 @@ use Net_ACME_Example ();
 
 Net_ACME_Example::do_example(
     sub {
-        my ( $domain, $cmb_ar, $key_jwk ) = @_;
+        my ( $domain, $cmb_ar, $reg ) = @_;
 
         return if @$cmb_ar > 1;
 
@@ -21,7 +21,7 @@ Net_ACME_Example::do_example(
 
         return if $c->type() ne 'dns-01';
 
-        my $kauthz = $c->make_key_authz( $key_jwk );
+        my $kauthz = $c->make_key_authz( $reg->key() );
 
         my $sha = Digest::SHA::sha256($kauthz);
         my $b64 = MIME::Base64::encode_base64url($sha);
